@@ -145,27 +145,34 @@ class ThresholdEvaluator(BaseEvaluator):
 
         return '\n'.join(report)
 
-    def plot_roc_auc(self, with_plots: bool = True):
+    def plot_roc_auc(self):
+        label = "{} AUC={:.2f}"
 
-        # Plot test roc
+        # Plot test ROC
         plt.figure()
         fpr, tpr, thresholds = metrics.roc_curve(self.y_test, self.probabilities)
-        plt.plot(fpr, tpr, label='test')
+        plt.plot(fpr, tpr, label=label.format('test',
+                                              metrics.auc(fpr, tpr)
+                                              )
+                 )
 
         # Plot train
         probabilities = self.model.predict_proba(self.X_train)[:, 1]
         fpr, tpr, thresholds = metrics.roc_curve(self.y_train, probabilities)
-        if with_plots:
-            plt.plot(fpr, tpr, label='train')
-            plt.plot([0, 1], [0, 1], 'r--', label='random guess')
-            plt.title("Area under the ROC = {}".format(self.test_roc_auc_test), fontsize=18)
-            plt.legend()
-            plt.show()
+        plt.plot(fpr, tpr, label=label.format('train',
+                                              metrics.auc(fpr, tpr)
+                                              )
+                 )
 
-            rcl_per_disp = metrics.plot_precision_recall_curve(self.model, self.X_test, self.y_test)
-            plt.show()
+        plt.plot([0, 1], [0, 1], 'r--', label='random guess')
+        plt.title("ROC", fontsize=18)
+        plt.legend()
+        plt.show()
 
-            roc_disp = metrics.plot_roc_curve(self.model, self.X_test, self.y_test)
-            plt.cla()
-            plt.clf()
-            plt.close()
+        rcl_per_disp = metrics.plot_precision_recall_curve(self.model, self.X_test, self.y_test)
+        plt.show()
+
+        roc_disp = metrics.plot_roc_curve(self.model, self.X_test, self.y_test)
+        plt.cla()
+        plt.clf()
+        plt.close()
