@@ -14,7 +14,7 @@ class MLFlowModelProbabilityWrapper(mlflow.pyfunc.PythonModel):
 
 
 class RegisterProbabilityModel:
-    def __init__(self, model: Any, model_name: str, xtrain: Union[pd.DatFrame, np.ndarray], dependencies: list=[]):
+    def __init__(self, model: Any, model_name: str, xtrain: Union[pd.DataFrame, np.ndarray], dependencies: list=[]):
         self.wrapper_model = MLFlowModelProbabilityWrapper(model)
         self.xtrain = xtrain
         self.dependencies = dependencies
